@@ -1,10 +1,10 @@
-import pathlib
+from .cache import init_cache
 from .connections import Connection, SilentConnection
 
 
 __name__ = "easy_requests"
-__folder__ = str(pathlib.Path(__file__).parent)
 __all__ = [
+    "init_cache",
     "Connection", 
     "SilentConnection",
 ]
